@@ -484,14 +484,16 @@ def dataCorrectorSetUp(test):
     test.globs['plone'] = portal
     test.globs['transmogrifier'].context = test.globs['plone']
 
+    from collective.transmogrifier.interfaces import ITransmogrifier
     from quintagroup.transmogrifier.interfaces import IExportDataCorrector, \
         IImportDataCorrector
 
     class MockExportAdapter(object):
         implements(IExportDataCorrector)
-        adapts(MockPortal)
-        def __init__(self, context):
+        adapts(MockPortal, ITransmogrifier)
+        def __init__(self, context, transmogrifier):
             self.context = context
+            self.transmogrifier = transmogrifier
 
         def __call__(self, data):
             return "modified export data"
@@ -500,9 +502,10 @@ def dataCorrectorSetUp(test):
 
     class MockImportAdapter(object):
         implements(IImportDataCorrector)
-        adapts(MockPortal)
-        def __init__(self, context):
+        adapts(MockPortal, ITransmogrifier)
+        def __init__(self, context, transmogrifier):
             self.context = context
+            self.transmogrifier = transmogrifier
 
         def __call__(self, data):
             return "modified import data"
@@ -809,7 +812,7 @@ def binarySetUp(test):
             if self._current_field == 'file':
                 return 'binary data'
             else:
-                return ''
+                return 'image'
 
         def getMutator(self, obj):
             return self
@@ -926,6 +929,102 @@ def catalogSourceSetUp(test):
     test.globs['plone'] = portal
     test.globs['transmogrifier'].context = test.globs['plone']
 
+def flushCacheSetUp(test):
+    sectionsSetUp(test)
+    
+    class DataBase(object):
+        def __init__(self, context):
+            self.context = context
+        
+        def cacheMinimize(self):
+            self.context.cacheMinimized += 1
+
+        def _getDB(self):
+            return self
+    
+    class DataBasePanel(object):
+        def __init__(self, context):
+            self.context = context
+        
+        def getDatabaseNames(self):
+            return ('main',)
+        
+        def __getitem__(self, key):
+            return DataBase(self.context)
+    
+    class ControlPanel(object):
+        def __init__(self, context):
+            self.Database = DataBasePanel(context)
+    
+    class MockPortal(object):
+        def __init__(self):
+            self.cacheMinimized = 0
+            self.Control_Panel = ControlPanel(self)
+        
+    test.globs['plone'] = MockPortal()
+    test.globs['transmogrifier'].context = test.globs['plone']
+
+
+def interfaceManagerSetUp(test):
+    sectionsSetUp(test)
+
+    from zope.annotation.interfaces import IAttributeAnnotatable
+    from zope.interface import alsoProvides as orig_alsoProvides
+    from Products.Archetypes.interfaces import IBaseObject
+
+    class MockPortal(object):
+
+        implements(
+            IAttributeAnnotatable,
+            IBaseObject,
+        )
+
+        _last_path = None
+        def unrestrictedTraverse(self, path, default):
+            if path[0] == '/':
+                return default # path is absolute
+            if isinstance(path, unicode):
+                return default
+            if path == 'not/existing/bar':
+                return default
+            if path.endswith('/notatcontent'):
+                return object()
+            self._last_path = path
+            return self
+
+        # implement portal_catalog reindex method
+        def reindexIndex(self, *args, **kwargs):
+            pass
+
+
+    updated = []
+    test.globs['updated'] = updated
+    def patch_alsoProvides(object, *interfaces):
+        updated.extend([i.__identifier__ for i in interfaces])
+        orig_alsoProvides(object, *interfaces)
+    quintagroup.transmogrifier.interfacemanager.alsoProvides = patch_alsoProvides
+
+    portal = MockPortal()
+    test.globs['plone'] = portal
+    test.globs['transmogrifier'].context = test.globs['plone']
+
+    class InterfaceManagerSource(SampleSource):
+        classProvides(ISectionBlueprint)
+        implements(ISection)
+
+        def __init__(self, *args, **kw):
+            super(InterfaceManagerSource, self).__init__(*args, **kw)
+            self.sample = (
+                dict(),
+                dict(_path='not/existing/bar'),
+                dict(_path='spam/eggs/notatcontent'),
+                dict(_path='spam/eggs/foo'),
+            )
+
+    provideUtility(InterfaceManagerSource,
+        name=u'quintagroup.transmogrifier.tests.interfacemanagersource')
+
+
 def test_suite():
     import sys
     suite = unittest.findTestCases(sys.modules[__name__])
@@ -966,5 +1065,11 @@ def test_suite():
         doctest.DocFileSuite(
             'catalogsource.txt',
             setUp=catalogSourceSetUp, tearDown=tearDown),
+        doctest.DocFileSuite(
+            'flushcache.txt',
+            setUp=flushCacheSetUp, tearDown=tearDown),
+        doctest.DocFileSuite(
+            'interfacemanager.txt',
+            setUp=interfaceManagerSetUp, tearDown=tearDown),
     ))
     return suite
